{% extends "core/__base.html" %}

{% block body %}
<div class="ui middle aligned center aligned grid">
  <div class="column">
    <h2 class="ui black image header">
      <div class="content">
        password reset
      </div>
    </h2>
    <div class="ui stacked segment">
      <p>Your request has been processed. Please check your email.</p>
    </div>
  </div>
</div>
{% endblock %}
