{% load static %}
<!doctype html>

<html lang="en">

<head>
  <meta charset="utf-8">

  <title>{% block title %}burl{% endblock %}</title>
  <meta name="description" content="{% block description %}brief url shortener{% endblock %}">
  <meta name="author" content="wryfi">

  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.4.1/semantic.min.css">
  <link rel="stylesheet" href="{% static "core/burl_styles.css" %}">

  {% block inlinestyle %}{% endblock %}
  {% block inlinescript %}{% endblock %}

</head>

<body>
  {% block body %}
  {% endblock %}
  <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.4.1/semantic.min.js"></script>
</body>


</html>