{% extends "core/__base.html" %}

{% block body %}
<div class="ui middle aligned center aligned grid">
  <div class="column">
    <h2 class="ui black image header">
      <div class="content">
        password reset
      </div>
    </h2>
    {{ form.non_field_errors }}
    {% if form.errors %}
    <div class="ui icon error message">
      <i class="exclamation triangle icon"></i>
      <div class="content">
        <div class="header">Validation Errors</div>
            {{ form.errors }}
      </div>
    </div>
    {% endif %}
    <form method="post" class="ui large form">
      {% csrf_token %}
      <div class="ui stacked segment">
        <div class="field">
          <div class="ui left icon input">
            <i class="envelope icon"></i>
            <input type="email" id="id_email" name="email" placeholder="email address">
          </div>
        </div>
        <button class="ui black button" type="submit">Reset</button>
      </div>
    </form>
  </div>
</div>
{% endblock %}